CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
81 lines
2.7 KiB
C++
81 lines
2.7 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
/**
|
|
* @addtogroup hipMemPoolImportPointer hipMemPoolImportPointer
|
|
* @{
|
|
* @ingroup MemoryTest
|
|
* `hipError_t hipMemPoolImportPointer(
|
|
void** dev_ptr,
|
|
hipMemPool_t mem_pool,
|
|
hipMemPoolPtrExportData* export_data) ` -
|
|
* Import a memory pool allocation from another process.
|
|
*/
|
|
|
|
#include "mempool_common.hh"
|
|
|
|
constexpr int DATA_SIZE = 1024 * 1024;
|
|
constexpr size_t byte_size = DATA_SIZE * sizeof(int);
|
|
|
|
/**
|
|
* Test Description
|
|
* ------------------------
|
|
* - Negative Tests for hipMemPoolImportPointer.
|
|
* ------------------------
|
|
* - unit/memory/hipMemPoolImportPointer.cc
|
|
* Test requirements
|
|
* ------------------------
|
|
* - Host specific (LINUX)
|
|
* - HIP_VERSION >= 6.2
|
|
*/
|
|
HIP_TEST_CASE(Unit_hipMemPoolImportPointer_Negative) {
|
|
hipMemPoolPtrExportData ptrExp;
|
|
hipShareableHdl sharedHandle;
|
|
hipMemPoolProps pool_props{};
|
|
hipMemPool_t mempoolPfd;
|
|
checkMempoolSupported(0)
|
|
|
|
#if HT_WIN
|
|
hipMemAllocationHandleType handleType = hipMemHandleTypeWin32;
|
|
#else
|
|
hipMemAllocationHandleType handleType = hipMemHandleTypePosixFileDescriptor;
|
|
#endif
|
|
|
|
// Create mempool with OS specific handle type
|
|
pool_props.allocType = hipMemAllocationTypePinned;
|
|
pool_props.location.id = 0;
|
|
pool_props.location.type = hipMemLocationTypeDevice;
|
|
pool_props.handleTypes = handleType;
|
|
HIP_CHECK(hipMemPoolCreate(&mempoolPfd, &pool_props));
|
|
int* A_d;
|
|
HIP_CHECK(hipMallocFromPoolAsync(reinterpret_cast<void**>(&A_d), byte_size, mempoolPfd, 0));
|
|
HIP_CHECK(hipStreamSynchronize(0));
|
|
HIP_CHECK(hipMemPoolExportToShareableHandle(&sharedHandle, mempoolPfd,
|
|
handleType, 0));
|
|
HIP_CHECK(hipMemPoolExportPointer(&ptrExp, A_d));
|
|
hipMemPool_t mempoolImp;
|
|
HIP_CHECK(hipMemPoolImportFromShareableHandle(&mempoolImp, (void*)sharedHandle,
|
|
handleType, 0));
|
|
void* ptrImp;
|
|
SECTION("Passing nullptr as import data") {
|
|
HIP_CHECK_ERROR(hipMemPoolImportPointer(nullptr, mempoolImp, &ptrExp), hipErrorInvalidValue);
|
|
}
|
|
SECTION("Passing nullptr as imported mempool") {
|
|
HIP_CHECK_ERROR(hipMemPoolImportPointer(&ptrImp, nullptr, &ptrExp), hipErrorInvalidValue);
|
|
}
|
|
SECTION("Passing nullptr as exported pointer") {
|
|
HIP_CHECK_ERROR(hipMemPoolImportPointer(&ptrImp, mempoolImp, nullptr), hipErrorInvalidValue);
|
|
}
|
|
HIP_CHECK(hipFree(reinterpret_cast<void*>(A_d)));
|
|
HIP_CHECK(hipMemPoolDestroy(mempoolPfd));
|
|
HIP_CHECK(hipMemPoolDestroy(mempoolImp));
|
|
}
|
|
|
|
/**
|
|
* End doxygen group MemoryTest.
|
|
* @}
|
|
*/
|